==> adsprod-facade-1.1.2-sources.jar: com/bxm/adsprod/facade/ticket/ClickRequest.java <==
package com.bxm.adsprod.facade.ticket;

import com.bxm.warcar.validate.annotation.ValidateNotNull;
import org.apache.commons.lang.builder.ToStringBuilder;
import org.apache.commons.lang.builder.ToStringStyle;

import java.io.Serializable;
import java.math.BigInteger;

/**
 * <h3>Click request</h3>
 *
 * @author allen
 * @since V1.0.0 2017/12/26
 */
public class ClickRequest implements Serializable {

    private static final long serialVersionUID = -269873396903039069L;
    @ValidateNotNull
    private String uid;
    @ValidateNotNull
    private BigInteger ticketId;
    @ValidateNotNull
    private String position;
    /**
     * 这次点击是否是有效点击
     */
    private boolean valid = false;
    /**
     * 点击单据，这次有效点击必须是有单据可寻
     */
    private String billid;

    public ClickRequest() {
    }

    public static ClickRequest of(String uid, BigInteger ticketId) {
        return new ClickRequest(uid, ticketId);
    }

    public static ClickRequest of(String uid, BigInteger ticketId, String position) {
        return new ClickRequest(uid, ticketId, position);
    }

    public static ClickRequest of(String uid, BigInteger ticketId, String position, boolean valid, String billid) {
        return new ClickRequest(uid, ticketId, position, valid, billid);
    }

    public ClickRequest(String uid, BigInteger ticketId) {
        this.uid = uid;
        this.ticketId = ticketId;
    }

    public ClickRequest(String uid, BigInteger ticketId, String position) {
        this.uid = uid;
        this.ticketId = ticketId;
        this.position = position;
    }

    public ClickRequest(String uid, BigInteger ticketId, String position, boolean valid, String billid) {
        this.uid = uid;
        this.ticketId = ticketId;
        this.position = position;
        this.valid = valid;
        this.billid = billid;
    }

    public String getUid() {
        return uid;
    }

    public void setUid(String uid) {
        this.uid = uid;
    }

    public BigInteger getTicketId() {
        return ticketId;
    }

    public void setTicketId(BigInteger ticketId) {
        this.ticketId = ticketId;
    }

    public String getPosition() {
        return position;
    }

    public void setPosition(String position) {
        this.position = position;
    }

    public boolean isValid() {
        return valid;
    }

    public void setValid(boolean valid) {
        this.valid = valid;
    }

    public String getBillid() {
        return billid;
    }

    public void setBillid(String billid) {
        this.billid = billid;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this, ToStringStyle.SHORT_PREFIX_STYLE);
    }
}

==> adsprod-facade-1.2.5-sources.jar: com/bxm/adsprod/facade/ticket/ClickRequest.java <==
package com.bxm.adsprod.facade.ticket;

import com.bxm.warcar.validate.annotation.ValidateNotNull;
import org.apache.commons.lang.builder.ToStringBuilder;
import org.apache.commons.lang.builder.ToStringStyle;

import java.io.Serializable;
import java.math.BigInteger;

/**
 * <h3>Click request</h3>
 *
 * @author allen
 * @since V1.0.0 2017/12/26
 */
public class ClickRequest implements Serializable {

    private static final long serialVersionUID = -269873396903039069L;
    @ValidateNotNull
    private String uid;
    @ValidateNotNull
    private BigInteger ticketId;
    @ValidateNotNull
    private String position;
    /**
     * 这次点击是否是有效点击
     */
    private boolean valid = false;
    /**
     * 点击单据，这次有效点击必须是有单据可寻
     */
    private String billid;
    /**
     * 素材ID
     */
    private BigInteger assetsId;

    public ClickRequest() {
    }

    public static ClickRequest of(String uid, BigInteger ticketId) {
        return new ClickRequest(uid, ticketId);
    }

    public static ClickRequest of(String uid, BigInteger ticketId, String position) {
        return new ClickRequest(uid, ticketId, position);
    }

    public static ClickRequest of(String uid, BigInteger ticketId, String position, boolean valid, String billid) {
        return new ClickRequest(uid, ticketId, position, valid, billid);
    }

    public static ClickRequest of(String uid, BigInteger ticketId, String position, boolean valid, String billid, BigInteger assetsId) {
        return new ClickRequest(uid, ticketId, position, valid, billid, assetsId);
    }

    public ClickRequest(String uid, BigInteger ticketId) {
        this(uid, ticketId, null);
    }

    public ClickRequest(String uid, BigInteger ticketId, String position) {
        this(uid, ticketId, position, false, null);
    }

    public ClickRequest(String uid, BigInteger ticketId, String position, boolean valid, String billid) {
        this(uid, ticketId, position, valid, billid, null);
    }

    public ClickRequest(String uid, BigInteger ticketId, String position, boolean valid, String billid, BigInteger assetsId) {
        this.uid = uid;
        this.ticketId = ticketId;
        this.position = position;
        this.valid = valid;
        this.billid = billid;
        this.assetsId = assetsId;
    }

    public String getUid() {
        return uid;
    }

    public void setUid(String uid) {
        this.uid = uid;
    }

    public BigInteger getTicketId() {
        return ticketId;
    }

    public void setTicketId(BigInteger ticketId) {
        this.ticketId = ticketId;
    }

    public String getPosition() {
        return position;
    }

    public void setPosition(String position) {
        this.position = position;
    }

    public boolean isValid() {
        return valid;
    }

    public void setValid(boolean valid) {
        this.valid = valid;
    }

    public String getBillid() {
        return billid;
    }

    public void setBillid(String billid) {
        this.billid = billid;
    }

    public BigInteger getAssetsId() {
        return assetsId;
    }

    public void setAssetsId(BigInteger assetsId) {
        this.assetsId = assetsId;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this, ToStringStyle.SHORT_PREFIX_STYLE);
    }
}
